public inbox for gcc-patches@gcc.gnu.org
 help / color / mirror / Atom feed
* [PATCH 2/4] Testcase adjustments for birth CLOBBERs
@ 2022-02-04 13:49 Richard Biener
  0 siblings, 0 replies; only message in thread
From: Richard Biener @ 2022-02-04 13:49 UTC (permalink / raw)
  To: gcc-patches

Mostly decl shuffling, using patterns to make the scans less
error-prone and adjustments for now appearing birth CLOBBERs.

2022-02-02  Richard Biener  <rguenther@suse.de>

	* gcc.dg/pr87052.c: Adjust.
	* gcc.dg/tm/memopt-3.c: Likewise.
	* gcc.dg/torture/pta-ptrarith-1.c: Likewise.
	* gcc.dg/torture/pta-ptrarith-2.c: Likewise.
	* gcc.dg/tree-ssa/20031015-1.c: Likewise.
	* gcc.dg/tree-ssa/alias-19.c: Likewise.
	* gcc.dg/tree-ssa/dse-points-to.c: Likewise.
	* gcc.dg/tree-ssa/pta-callused.c: Likewise.
---
 gcc/testsuite/gcc.dg/pr87052.c                | 3 ++-
 gcc/testsuite/gcc.dg/tm/memopt-3.c            | 2 +-
 gcc/testsuite/gcc.dg/torture/pta-ptrarith-1.c | 2 +-
 gcc/testsuite/gcc.dg/torture/pta-ptrarith-2.c | 2 +-
 gcc/testsuite/gcc.dg/tree-ssa/20031015-1.c    | 6 ++++--
 gcc/testsuite/gcc.dg/tree-ssa/alias-19.c      | 2 +-
 gcc/testsuite/gcc.dg/tree-ssa/dse-points-to.c | 2 +-
 gcc/testsuite/gcc.dg/tree-ssa/pta-callused.c  | 2 +-
 8 files changed, 12 insertions(+), 9 deletions(-)

diff --git a/gcc/testsuite/gcc.dg/pr87052.c b/gcc/testsuite/gcc.dg/pr87052.c
index 18e092c4674..c67d9ae02f8 100644
--- a/gcc/testsuite/gcc.dg/pr87052.c
+++ b/gcc/testsuite/gcc.dg/pr87052.c
@@ -37,5 +37,6 @@ void test (void)
    { dg-final { scan-tree-dump-times "b = \"a\\\\x00bc\";"  1 "gimple" } }
    { dg-final { scan-tree-dump-times "c = \"\";"  1 "gimple" } }
    { dg-final { scan-tree-dump-times "d = { *};"  1 "gimple" } }
-   { dg-final { scan-tree-dump-times "e = "  1 "gimple" } }
+   { dg-final { scan-tree-dump-times "e = "  3 "gimple" } }
+   { dg-final { scan-tree-dump-times "e = {CLOBBER\\(birth\\)}"  2 "gimple" } }
    { dg-final { scan-tree-dump-times "e = {CLOBBER\\(eol\\)}"  1 "gimple" } }  */
diff --git a/gcc/testsuite/gcc.dg/tm/memopt-3.c b/gcc/testsuite/gcc.dg/tm/memopt-3.c
index 5316f9cae20..299494a1d2b 100644
--- a/gcc/testsuite/gcc.dg/tm/memopt-3.c
+++ b/gcc/testsuite/gcc.dg/tm/memopt-3.c
@@ -17,4 +17,4 @@ int f()
   return lala.x[0];
 }
 
-/* { dg-final { scan-tree-dump-times "logging: lala.x\\\[i_4\\\]" 1 "tmmark" } } */
+/* { dg-final { scan-tree-dump-times "logging: lala.x\\\[i_\[0-9\]+\\\]" 1 "tmmark" } } */
diff --git a/gcc/testsuite/gcc.dg/torture/pta-ptrarith-1.c b/gcc/testsuite/gcc.dg/torture/pta-ptrarith-1.c
index 85b68068b12..4e272222b12 100644
--- a/gcc/testsuite/gcc.dg/torture/pta-ptrarith-1.c
+++ b/gcc/testsuite/gcc.dg/torture/pta-ptrarith-1.c
@@ -32,4 +32,4 @@ int main()
   return 0;
 }
 
-/* { dg-final { scan-tree-dump "ESCAPED = {\[^\n\}\]* i f \[^\n\}\]*}" "alias" } } */
+/* { dg-final { scan-tree-dump "ESCAPED = {\[^\n\}\]* (i f|f i) \[^\n\}\]*}" "alias" } } */
diff --git a/gcc/testsuite/gcc.dg/torture/pta-ptrarith-2.c b/gcc/testsuite/gcc.dg/torture/pta-ptrarith-2.c
index 4f5556acc93..5083d6367fa 100644
--- a/gcc/testsuite/gcc.dg/torture/pta-ptrarith-2.c
+++ b/gcc/testsuite/gcc.dg/torture/pta-ptrarith-2.c
@@ -32,4 +32,4 @@ int main()
 
 /* In theory = { i } is the correct solution.  But it's not easy to scan
    for that reliably, so just use what we create now.  */
-/* { dg-final { scan-tree-dump "= { i j }" "alias" } } */
+/* { dg-final { scan-tree-dump "= { (i j|j i) }" "alias" } } */
diff --git a/gcc/testsuite/gcc.dg/tree-ssa/alias-19.c b/gcc/testsuite/gcc.dg/tree-ssa/alias-19.c
index 330ec001705..15f44a1c284 100644
--- a/gcc/testsuite/gcc.dg/tree-ssa/alias-19.c
+++ b/gcc/testsuite/gcc.dg/tree-ssa/alias-19.c
@@ -25,4 +25,4 @@ int main()
   return 0;
 }
 
-/* { dg-final { scan-tree-dump "q_. = { a b }" "alias" } } */
+/* { dg-final { scan-tree-dump "q_. = { (a b|b a) }" "alias" } } */
diff --git a/gcc/testsuite/gcc.dg/tree-ssa/dse-points-to.c b/gcc/testsuite/gcc.dg/tree-ssa/dse-points-to.c
index 762d6720143..fced53fe50b 100644
--- a/gcc/testsuite/gcc.dg/tree-ssa/dse-points-to.c
+++ b/gcc/testsuite/gcc.dg/tree-ssa/dse-points-to.c
@@ -11,4 +11,4 @@ f ()
   return a;
 }
 
-/* { dg-final { scan-tree-dump-times "Deleted dead store.*p_1" 1 "dse1"} } */
+/* { dg-final { scan-tree-dump-times "Deleted dead store: \\*p_\[0-9\]+ = 1" 1 "dse1"} } */
diff --git a/gcc/testsuite/gcc.dg/tree-ssa/pta-callused.c b/gcc/testsuite/gcc.dg/tree-ssa/pta-callused.c
index b9a57d8d135..45826415d56 100644
--- a/gcc/testsuite/gcc.dg/tree-ssa/pta-callused.c
+++ b/gcc/testsuite/gcc.dg/tree-ssa/pta-callused.c
@@ -22,5 +22,5 @@ int bar (int b)
   return *foo (&q);
 }
 
-/* { dg-final { scan-tree-dump "CALLUSED\\(\[0-9\]+\\) = { ESCAPED NONLOCAL f.* i q }" "alias" } } */
+/* { dg-final { scan-tree-dump "CALLUSED\\(\[0-9\]+\\) = { ESCAPED NONLOCAL (i f.*|f.* i) q }" "alias" } } */
 
diff --git a/gcc/testsuite/gcc.dg/tree-ssa/20031015-1.c b/gcc/testsuite/gcc.dg/tree-ssa/20031015-1.c
index faa6853f571..b97b4475132 100644
--- a/gcc/testsuite/gcc.dg/tree-ssa/20031015-1.c
+++ b/gcc/testsuite/gcc.dg/tree-ssa/20031015-1.c
@@ -13,5 +13,7 @@ main(void)
   return 0;
 }
 
-/* The VDEF comes from the initial assignment, the asm, and the clobber.  */
-/* { dg-final { scan-tree-dump-times "DEF" 3 "alias" } } */
+/* The VDEF comes from the birth clobber, initial assignment, the asm, and
+   the clobber.
+   ???  The birth clobber is duplicate.  */
+/* { dg-final { scan-tree-dump-times "DEF" 5 "alias" } } */
-- 
2.34.1


^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2022-02-04 13:49 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2022-02-04 13:49 [PATCH 2/4] Testcase adjustments for birth CLOBBERs Richard Biener

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).